@@ -31,6 +31,8 @@ class OpaqueConstruction(LayeredConstruction):
         * solar_reflectance_index
     """
 
+    _CREATED_OBJECTS = []
+
     __slots__ = ("area",)
 
     def __init__(self, Name, Layers, **kwargs):
@@ -45,8 +47,8 @@ class OpaqueConstruction(LayeredConstruction):
         super(OpaqueConstruction, self).__init__(Name, Layers, **kwargs)
         self.area = 1
 
-        # Only at the end append self to CREATED_OBJECTS
-        self.CREATED_OBJECTS.append(self)
+        # Only at the end append self to _CREATED_OBJECTS
+        self._CREATED_OBJECTS.append(self)
 
     @property
     def r_value(self):
@@ -406,7 +408,7 @@ class OpaqueConstruction(LayeredConstruction):
         return OpaqueConstruction(
             Name="InternalMass",
             Layers=[MaterialLayer(Material=mat, Thickness=0.15)],
-            Category="InternalMass",
+            Category="Internal Mass",
             **kwargs,
         )
 
@@ -463,7 +465,7 @@ class OpaqueConstruction(LayeredConstruction):
             # Iterate over the construction's layers
             material = epbunch.get_referenced_object(layer)
             if material:
-                o = OpaqueMaterial.from_epbunch(material, allow_duplicates=True)
+                o = OpaqueMaterial.from_epbunch(material, allow_duplicates=False)
                 try:
                     thickness = material.Thickness
                 except BadEPFieldError:
@@ -491,7 +493,7 @@ class OpaqueConstruction(LayeredConstruction):
 
         return data_dict
 
-    def mapping(self, validate=True):
+    def mapping(self, validate=False):
         """Get a dict based on the object properties, useful for dict repr.
 
         Args:
